import { useEffect, useMemo, useState } from 'react';
import { useColorFunction } from '../ColorFunctionContext';
import { ColorRangePicker } from './ColorRangePicker';

type RGBAssembleProps = {
  color: string | null;
  onChange: (color: string) => void;
};

export function RGBAssemble({ color = '000000', onChange }: RGBAssembleProps) {
  const { colorFn } = useColorFunction();
  const rgbComponents = useMemo(() => {
    try {
      const [r, g, b] = colorFn?.represent_rgb(color) ?? [0, 0, 0];
      return [r, g, b];
    } catch (error) {
      console.error('[Convert RGB]', error);
    }
    return [0, 0, 0];
  }, [color]);
  const [r, setR] = useState(0);
  const [g, setG] = useState(0);
  const [b, setB] = useState(0);

  useEffect(() => {
    try {
      const newColor = colorFn?.rgb_to_hex(r, g, b) ?? '000000';
      onChange(newColor);
    } catch (error) {
      console.error('[Convert RGB]', error);
    }
  }, [r, g, b]);
  useEffect(() => {
    setR(rgbComponents[0]);
    setG(rgbComponents[1]);
    setB(rgbComponents[2]);
  }, []);

  return (
    <div>
      <ColorRangePicker
        title="Red"
        gradient="linear-gradient(to right, #000000, #ff0000)"
        max={255}
        step={1}
        value={r}
        onChange={setR}
      />
      <ColorRangePicker
        title="Green"
        gradient="linear-gradient(to right, #000000, #00ff00)"
        max={255}
        step={1}
        value={g}
        onChange={setG}
      />
      <ColorRangePicker
        title="Blue"
        gradient="linear-gradient(to right, #000000, #0000ff)"
        max={255}
        step={1}
        value={b}
        onChange={setB}
      />
    </div>
  );
}
